/*This file is licensed under the Mozilla Public License 2.0 (the "License").  You may not use this file except in compliance with the License. See the License for the specific language governing permissions and limitations under the License.*/


# Required Versions
terraform {
  required_version = ">= 0.13.0"

  required_providers {
    azurerm = {
      source  = "hashicorp/azurerm"
      version = ">= 3.37.0"    
    }
    azuread = {
        source  = "hashicorp/azuread"
        version = ">= 2.0.0"
    }
  }
}

# Required Providers
provider "azurerm" {
  features {}
# Uncomment block if running Terraform through a Service Principal and NOT from the Azure Cloud Shell
/*  
  subscription_id = "INSERT-SUBSCRIPTION-ID"
  tenant_id = "INSERT-TENANT-ID"
  client_id = "INSERT-ID-OF-CURRENT-SERVICE-PRINCIPAL"
  client_secret = "INSERT-SECRET-KEY-FOR-CURRENT-SERVICE-PRINCIPAL"
*/


}

provider "azuread" {}


# Initiates the CSPM Configuration module 
module "AWNCloudScan" {
    source = "./modules"
}


# Required Outputs for Portal Registration
## Use `terraform output portal_registration` to output these values at any time
output "registration" {
 value = [format("Directory ID: ${module.AWNCloudScan.Directory_ID}"), format("Subscription ID: ${module.AWNCloudScan.Subscription_ID}"), format("Application ID: ${module.AWNCloudScan.Application_ID}")]
}

## Use `terraform output -raw secret_key` to output this value at any time. Note that using `-raw` will expose the secret. 
### Secret is set to reset every 365 days. This can be changed by modifying the resource in AWNCloudScanConfig > ScanConfig.tf 
output "secret_key" {
    value = module.AWNCloudScan.Secret_Key
    sensitive = true        
}

# Required Output for Debugging / Troubleshooting Permission Issues
## Use `terraform output assigned_roles` to output these values at any time 
output "assigned_roles" {
  value = [module.AWNCloudScan.security_reader_role_assignment, module.AWNCloudScan.log_analytics_role_assignment]
}



