# Required - Reads environment configuration 
data "azurerm_subscription" "primary" {}
data "azuread_client_config" "current" {}

# Required - Creates the Arctic Wolf Cloud Scan Application
resource "azuread_application" "cspm" {
  display_name = "AWN Cloud Scanner"
  owners       = [data.azuread_client_config.current.object_id]
}

# Required - Assigns a Service Principal to the Arctic Wolf Cloud Scan Applicaiton
resource "azuread_service_principal" "cspm" {
  application_id               = azuread_application.cspm.application_id
}

# Required - Establishes an expiration date for the Secrets Key
resource "time_rotating" "cspm" {
  rotation_days = 365     # The Secret Key will be reset every 365 days. The new secret key should be provided to Arctic Wolf at this time to prevent service disruptions. 
}

# Required - Creates the Secrets Key
resource "azuread_application_password" "cspm" {
  application_object_id = azuread_application.cspm.object_id
  display_name = "AWN Cloud Scan Credentials"
  rotate_when_changed = {
    rotation = time_rotating.cspm.id
  }
}

# Required - Assigns the necessary permisisons to the Arctic Wolf Cloud Scan Application 
module "application_roles" {
  source  = "./role_assignments"
  depends_on = [
    azuread_service_principal.cspm
  ]

  display_name = azuread_application.cspm.display_name
}

### Required Outputs
# Returns Arctic Wolf Cloud Scan Application values needed for Portal registration
output "Directory_ID" {
  value = azuread_service_principal.cspm.application_tenant_id
}

output "Subscription_ID" {
  value = data.azurerm_subscription.primary.id
}

output "Application_ID" {
  value = azuread_service_principal.cspm.application_id
}

output "Secret_Key" {
  value = azuread_application_password.cspm.value
  sensitive = false   # Note that the credentials will be displayed in the output. Setting this to True will redact the secret. 
}

# Returns Assigned Permissions (Required)
output "security_reader_role_assignment" {
  value = module.application_roles.security_reader_role_assignment
}

output "log_analytics_role_assignment" {
  value = module.application_roles.log_analytics_role_assignment
}

### Optional Outputs
# Returns Arctic Wolf Application Name (Optional)
output "Application_Name" {
  value = azuread_service_principal.cspm.display_name
}



